<?php

namespace Lc\CaracoleBundle\Form\User;

use Lc\CaracoleBundle\Model\User\UserMerchantInterface;
use Lc\SovBundle\Definition\RolesDefinitionInterface;
use Lc\SovBundle\Doctrine\EntityManager;
use Lc\SovBundle\Model\User\UserInterface;
use Lc\SovBundle\Translation\TranslatorAdmin;
use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\Extension\Core\Type\CheckboxType;
use Symfony\Component\Form\Extension\Core\Type\ChoiceType;
use Symfony\Component\Form\Extension\Core\Type\EmailType;
use Symfony\Component\Form\Extension\Core\Type\SubmitType;
use Symfony\Component\Form\Extension\Core\Type\TextType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\OptionsResolver\OptionsResolver;
use Symfony\Component\Security\Core\Authorization\AuthorizationCheckerInterface;

class UserMerchantFormType extends AbstractType
{
    protected $em;
    protected $rolesDefinition;
    protected $translatorAdmin;
    protected $authorizationChecker;

    public function __construct(
            EntityManager $em,
            TranslatorAdmin $translatorAdmin,
            RolesDefinitionInterface $rolesDefinition,
            AuthorizationCheckerInterface $authorizationChecker
    ) {
        $this->em = $em;
        $this->rolesDefinition = $rolesDefinition;
        $this->translatorAdmin = $translatorAdmin;
        $this->authorizationChecker = $authorizationChecker;
    }

    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        $entityName = $this->em->getEntityName(UserInterface::class);

        $builder->add(
                'firstname',
                TextType::class,
                array(
                        'mapped' => false,
                )
        );

        $builder->add(
                'lastname',
                TextType::class,
                array(
                        'mapped' => false,
                )
        );

        $builder->add(
                'email',
                EmailType::class,
                array(
                        'mapped' => false,
                )
        );

        $builder->add(
                'creditActive',
                CheckboxType::class,
                array(
                        'required' => false,
                )
        );

        $builder->add(
                'roles',
                ChoiceType::class,
                array(
                        'choices' => $this->rolesDefinition->getRolesList(),
                        'multiple' => true,
                )

        );


        $builder->add(
                'submit',
                SubmitType::class,
                [
                        'label' => $this->translatorAdmin->transAction('save'),
                ]
        );
    }

    /**
     * {@inheritdoc}
     */
    public function configureOptions(OptionsResolver $resolver)
    {
        $resolver->setDefaults(
                [
                        'data_class' => $this->em->getEntityName(UserMerchantInterface::class),
                ]
        );
    }
}
